@@ -40,14 +40,6 @@ def identify_servers(path=os.getcwd()):
             else:
                 serverDir[os.path.basename(os.path.normpath(subdir))] = subdir
 
-
-
-# use this to execute functions you want to try
-def test():
-    """For debugging only
-    """
-    print(serverDir)
-
 # os.walk, but allows for level distinction
 def walklevel(some_dir, level=1):
     some_dir = some_dir.rstrip(os.path.sep)
@@ -186,5 +178,5 @@ def GUI():
 
 if __name__ == "__main__":
     parser = argh.ArghParser()
-    parser.add_commands([setup, run, update, test])
+    parser.add_commands([setup, run, update])
     parser.dispatch()
